@@ -101,29 +101,19 @@ class StudentDormitoryRoomLink(Base):
     """
     __tablename__ = 'univer_student_dormitory_room_link'
 
-    # Студент
     student_id = Column(ForeignKey('univer_students.students_id'), primary_key=True)
-    student = relationship('Student')
-
-    # Комната общежития
+    student = relationship('Student')  # Студент
     dormitory_room_id = Column(ForeignKey('univer_dormitory_rooms.dormitory_room_id'), primary_key=True)
-    dormitory_room = relationship('DormitoryRoom')
-
-    # Год
-    year = Column(Integer)
-
-    # Дата и время создания
-    created = Column(DateTime)
-
-    # Заявление общежития
-    dormitory_applicant_id = Column(ForeignKey('univer_dormitory_applicant.dormitory_applicant_id'))
-    dormitory_applicant = relationship('DormitoryApplicant')
+    dormitory_room = relationship('DormitoryRoom')  # Комната общежития
+    year = Column(Integer)  # Год
+    created_at = Column('created', DateTime)  # Дата и время создания
+    applicant_id = Column(ForeignKey('univer_dormitory_applicant.dormitory_applicant_id'))
+    applicant = relationship('DormitoryApplicant')  # Заявления общежития
 
     def __repr__(self):
-        return '<StudentDormitoryRoomLink {} (dormitory_applicant_id={})>'.format(self, self.dormitory_applicant_id)
-    
-    def __str__(self):
-        return '{} - {}'.format(self.student, self.dormitory_room)
+        return '<StudentDormitoryRoomLink (student_id={} dormitory_room_id={} year={} applicant_id={})>'.format(
+            self.student_id, self.dormitory_room_id, self.year, self.applicant_id
+        )
 
 
 class StudentDormitoryRoomSettleHistory(Base):
@@ -132,51 +122,35 @@ class StudentDormitoryRoomSettleHistory(Base):
     """
     __tablename__ = 'univer_student_dormitory_room_settle_history'
 
-    # Идентификатор
-    id = Column('history_id', Integer, primary_key=True)
-
-    # Студент
+    id = Column('history_id', Integer, primary_key=True)  # Идентификатор
     student_id = Column(ForeignKey('univer_students.students_id'))
-    student = relationship('Student')
-
-    # Комната общежития
+    student = relationship('Student')  # Студент
     dormitory_room_id = Column(ForeignKey('univer_dormitory_rooms.dormitory_room_id'))
-    dormitory_room = relationship('DormitoryRoom')
-
-    # Дата и время
-    date = Column('history_date', DateTime)
-
-    # Заявление общежития
-    dormitory_applicant_id = Column(ForeignKey('univer_dormitory_applicant.dormitory_applicant_id'))
-    dormitory_applicant = relationship('DormitoryApplicant')
-
-    # Общежитие
+    dormitory_room = relationship('DormitoryRoom')  # Комната общежития
+    date = Column('history_date', DateTime)  # Дата и время
+    user_id = Column(ForeignKey('univer_users.user_id'))
+    user = relationship('User')  # Пользователь
+    personnel_id = Column(ForeignKey('univer_personal.personal_id'))
+    personnel = relationship('Personnel')  # Сотрудник
+    applicant_id = Column(ForeignKey('univer_dormitory_applicant.dormitory_applicant_id'))
+    applicant = relationship('DormitoryApplicant')  # Заявления общежития
     dormitory_id = Column(ForeignKey('platonus_univer_dormitories.dormitoryID'))
-    dormitory = relationship('Dormitory')
-
-    # Тип приказа
-    order_type = Column(Integer)
-
-    # Дата и время приказа
-    order_date = Column(DateTime)
-
-    # Статус приказа
-    order_status = Column(Integer)
+    dormitory = relationship('Dormitory')  # Общежитие
+    order_type = Column(Integer)  # Тип приказа
+    order_date = Column(DateTime)  # Дата и время приказа
+    order_status = Column(Integer)  # Статус приказа
+    dormitory_room_size = Column('dormitory_room_size', Integer)  # Размер комнаты общежития
 
     def __repr__(self):
-        return '<StudentDormitoryRoomSettleHistory {} (id={} student_id={} dormitory_room_id={} date={} dormitory_applicant_id={} order_type={}'.format(
-            self,
+        return '<StudentDormitoryRoomSettleHistory (id={} student_id={} dormitory_room_id={} date={} applicant_id={} order_type={}'.format(
             self.id,
             self.student_id,
             self.dormitory_room_id,
             self.date,
-            self.dormitory_applicant_id,
+            self.applicant_id,
             self.order_type
         )
 
-    def __str__(self):
-        return str(self.student)
-
 
 class DormitoryStudentAccess(Base):
     """
